summaryrefslogtreecommitdiffstats
path: root/lib/xdsserver/sdks.go
diff options
context:
space:
mode:
Diffstat (limited to 'lib/xdsserver/sdks.go')
-rw-r--r--lib/xdsserver/sdks.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/xdsserver/sdks.go b/lib/xdsserver/sdks.go
index 6094045..4a7ba84 100644
--- a/lib/xdsserver/sdks.go
+++ b/lib/xdsserver/sdks.go
@@ -38,8 +38,8 @@ type SDKs struct {
stop chan struct{} // signals intentional stop
}
-// NewSDKs creates a new instance of SDKs
-func NewSDKs(ctx *Context) (*SDKs, error) {
+// SDKsConstructor creates a new instance of SDKs
+func SDKsConstructor(ctx *Context) (*SDKs, error) {
s := SDKs{
Context: ctx,
Sdks: make(map[string]*CrossSDK),